pub struct AsyncError<E: Error + 'static> { /* private fields */ }Expand description
Wraps an error with optional context.
Implementations
Sourceimpl<E: Error + 'static> AsyncError<E>
impl<E: Error + 'static> AsyncError<E>
Sourcepub fn with_context(self, context: String) -> Self
pub fn with_context(self, context: String) -> Self
Adds context to the error.
If the hooks feature is enabled, hooks may be triggered.
Sourcepub fn inner_error(&self) -> &E
pub fn inner_error(&self) -> &E
Returns a reference to the inner error.
Sourcepub fn invoke_hooks_once(&self) -> bool
pub fn invoke_hooks_once(&self) -> bool
Returns true if hooks have not been invoked yet, and marks them as invoked.