WithContext

Struct WithContext 

pub struct WithContext<Fut, E, C> { /* private fields */ }
Future wrapper produced by .with_context() to add error context.

Wraps the original future, and on error, attaches the context string lazily generated by the stored closure.