pub struct WithContext<Fut, E, C> { /* private fields */ }Expand description
Future wrapper produced by .with_context() to add error context.
Wraps the original future, and on error, attaches the context string lazily generated by the stored closure.